/**

	last.fm window

**/

#include <qmessagebox.h>

#include <klocale.h>

void frmLfm::init()
{
	lblInfo->setText("<i>" +
		i18n("If You don't have last.fm profile,") + "</i> <a href=http://last.fm/join><i>" +
		i18n("create it") + "</i></a>.");
	lblUser->setText(i18n("User"));
	lblPassword->setText(i18n("Password"));
	chkLfm->setText(i18n("support last.fm"));
	lblWarning->setText("<b><i>" + i18n("Warning") + "</i></b><br>" +
		i18n("last.fm support violates privacy") + "!");
	pshCancel->setText(i18n("Cancel"));
	setCaption(i18n("last.fm"));

	updatePercent(sldPercent->value());
}

void frmLfm::acceptTags()
{
	if ((chkLfm->isChecked()) && (txtUser->text().isEmpty() || txtPassword->text().isEmpty()))
	{
		QMessageBox::information(this, i18n("Info"), i18n("You must enter user and password."),
			QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
		return;
	}

	ok = true;
	hide();
}

void frmLfm::rejectTags()
{
	ok = false;
	hide();
}

void frmLfm::updatePercent(int v)
{
	lblPercent->setText(i18n("Playback percent complete") + " (" + QString::number(v) + "%).");
}
